from google.protobuf import struct_pb2 as _struct_pb2
from google.rpc import code_pb2 as _code_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Response(_message.Message):
    __slots__ = ["status_code", "error_message", "payload"]
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    status_code: _code_pb2.Code
    error_message: str
    payload: _struct_pb2.Struct
    def __init__(self, status_code: _Optional[_Union[_code_pb2.Code, str]] = ..., error_message: _Optional[str] = ..., payload: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.billing.v1alpha1``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.aio.client as client
import nebius.aio.request as request_1
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.billing.v1alpha1.calculator_pb2 as calculator_pb2
import nebius.api.nebius.billing.v1alpha1.calculator_service_pb2 as calculator_service_pb2
import nebius.api.nebius.billing.v1alpha1.offer_type_pb2 as offer_type_pb2
import nebius.api.nebius.compute.v1 as v1_1
import nebius.api.nebius.compute.v1.disk_service_pb2 as disk_service_pb2
import nebius.api.nebius.compute.v1.filesystem_service_pb2 as filesystem_service_pb2
import nebius.api.nebius.compute.v1.instance_service_pb2 as instance_service_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import typing as typing
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/billing/v1alpha1/calculator.proto
class ResourceSpec(pb_classes.Message):
    """
    Resource specification for cost estimation.
    Contains the specifications for creating and updating different types of resources.
    """
    
    __PB2_CLASS__ = calculator_pb2.ResourceSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ResourceSpec",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_resource_spec__(pb_classes.OneOf):
        name: builtins.str= "resource_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__()
            self._message: "ResourceSpec" = msg
    
    class __OneOfClass_resource_spec_compute_instance_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_instance_spec"] = "compute_instance_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateInstanceRequest":
            return self._message.compute_instance_spec
    
    class __OneOfClass_resource_spec_compute_instance_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_instance_update_spec"] = "compute_instance_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateInstanceRequest":
            return self._message.compute_instance_update_spec
    
    class __OneOfClass_resource_spec_compute_disk_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_disk_spec"] = "compute_disk_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateDiskRequest":
            return self._message.compute_disk_spec
    
    class __OneOfClass_resource_spec_compute_disk_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_disk_update_spec"] = "compute_disk_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateDiskRequest":
            return self._message.compute_disk_update_spec
    
    class __OneOfClass_resource_spec_compute_filesystem_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_filesystem_spec"] = "compute_filesystem_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.CreateFilesystemRequest":
            return self._message.compute_filesystem_spec
    
    class __OneOfClass_resource_spec_compute_filesystem_update_spec__(__OneOfClass_resource_spec__):
        field: typing.Literal["compute_filesystem_update_spec"] = "compute_filesystem_update_spec"
        
        def __init__(self, msg: "ResourceSpec") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "v1_1.UpdateFilesystemRequest":
            return self._message.compute_filesystem_update_spec
    
    @builtins.property
    def resource_spec(self) -> __OneOfClass_resource_spec_compute_instance_spec__|__OneOfClass_resource_spec_compute_instance_update_spec__|__OneOfClass_resource_spec_compute_disk_spec__|__OneOfClass_resource_spec_compute_disk_update_spec__|__OneOfClass_resource_spec_compute_filesystem_spec__|__OneOfClass_resource_spec_compute_filesystem_update_spec__|None:
        field_name_1: str|None = super().which_field_in_oneof("resource_spec")
        match field_name_1:
            case "compute_instance_spec":
                return self.__OneOfClass_resource_spec_compute_instance_spec__(self)
            case "compute_instance_update_spec":
                return self.__OneOfClass_resource_spec_compute_instance_update_spec__(self)
            case "compute_disk_spec":
                return self.__OneOfClass_resource_spec_compute_disk_spec__(self)
            case "compute_disk_update_spec":
                return self.__OneOfClass_resource_spec_compute_disk_update_spec__(self)
            case "compute_filesystem_spec":
                return self.__OneOfClass_resource_spec_compute_filesystem_spec__(self)
            case "compute_filesystem_update_spec":
                return self.__OneOfClass_resource_spec_compute_filesystem_update_spec__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        compute_instance_spec: "v1_1.CreateInstanceRequest|instance_service_pb2.CreateInstanceRequest|None|unset.UnsetType" = unset.Unset,
        compute_instance_update_spec: "v1_1.UpdateInstanceRequest|instance_service_pb2.UpdateInstanceRequest|None|unset.UnsetType" = unset.Unset,
        compute_disk_spec: "v1_1.CreateDiskRequest|disk_service_pb2.CreateDiskRequest|None|unset.UnsetType" = unset.Unset,
        compute_disk_update_spec: "v1_1.UpdateDiskRequest|disk_service_pb2.UpdateDiskRequest|None|unset.UnsetType" = unset.Unset,
        compute_filesystem_spec: "v1_1.CreateFilesystemRequest|filesystem_service_pb2.CreateFilesystemRequest|None|unset.UnsetType" = unset.Unset,
        compute_filesystem_update_spec: "v1_1.UpdateFilesystemRequest|filesystem_service_pb2.UpdateFilesystemRequest|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(compute_instance_spec, unset.UnsetType):
            self.compute_instance_spec = compute_instance_spec
        if not isinstance(compute_instance_update_spec, unset.UnsetType):
            self.compute_instance_update_spec = compute_instance_update_spec
        if not isinstance(compute_disk_spec, unset.UnsetType):
            self.compute_disk_spec = compute_disk_spec
        if not isinstance(compute_disk_update_spec, unset.UnsetType):
            self.compute_disk_update_spec = compute_disk_update_spec
        if not isinstance(compute_filesystem_spec, unset.UnsetType):
            self.compute_filesystem_spec = compute_filesystem_spec
        if not isinstance(compute_filesystem_update_spec, unset.UnsetType):
            self.compute_filesystem_update_spec = compute_filesystem_update_spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "compute_instance_spec",
            "compute_instance_update_spec",
            "compute_disk_spec",
            "compute_disk_update_spec",
            "compute_filesystem_spec",
            "compute_filesystem_update_spec",
            "resource_spec",
        ]
    
    @builtins.property
    def compute_instance_spec(self) -> "v1_1.CreateInstanceRequest|None":
        return super()._get_field("compute_instance_spec", explicit_presence=True,
        wrap=v1_1.CreateInstanceRequest,
        )
    @compute_instance_spec.setter
    def compute_instance_spec(self, value: "v1_1.CreateInstanceRequest|instance_service_pb2.CreateInstanceRequest|None") -> None:
        return super()._set_field("compute_instance_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_instance_update_spec(self) -> "v1_1.UpdateInstanceRequest|None":
        return super()._get_field("compute_instance_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateInstanceRequest,
        )
    @compute_instance_update_spec.setter
    def compute_instance_update_spec(self, value: "v1_1.UpdateInstanceRequest|instance_service_pb2.UpdateInstanceRequest|None") -> None:
        return super()._set_field("compute_instance_update_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_disk_spec(self) -> "v1_1.CreateDiskRequest|None":
        return super()._get_field("compute_disk_spec", explicit_presence=True,
        wrap=v1_1.CreateDiskRequest,
        )
    @compute_disk_spec.setter
    def compute_disk_spec(self, value: "v1_1.CreateDiskRequest|disk_service_pb2.CreateDiskRequest|None") -> None:
        return super()._set_field("compute_disk_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_disk_update_spec(self) -> "v1_1.UpdateDiskRequest|None":
        return super()._get_field("compute_disk_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateDiskRequest,
        )
    @compute_disk_update_spec.setter
    def compute_disk_update_spec(self, value: "v1_1.UpdateDiskRequest|disk_service_pb2.UpdateDiskRequest|None") -> None:
        return super()._set_field("compute_disk_update_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_filesystem_spec(self) -> "v1_1.CreateFilesystemRequest|None":
        return super()._get_field("compute_filesystem_spec", explicit_presence=True,
        wrap=v1_1.CreateFilesystemRequest,
        )
    @compute_filesystem_spec.setter
    def compute_filesystem_spec(self, value: "v1_1.CreateFilesystemRequest|filesystem_service_pb2.CreateFilesystemRequest|None") -> None:
        return super()._set_field("compute_filesystem_spec",value,explicit_presence=True,
        )
    
    @builtins.property
    def compute_filesystem_update_spec(self) -> "v1_1.UpdateFilesystemRequest|None":
        return super()._get_field("compute_filesystem_update_spec", explicit_presence=True,
        wrap=v1_1.UpdateFilesystemRequest,
        )
    @compute_filesystem_update_spec.setter
    def compute_filesystem_update_spec(self, value: "v1_1.UpdateFilesystemRequest|filesystem_service_pb2.UpdateFilesystemRequest|None") -> None:
        return super()._set_field("compute_filesystem_update_spec",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "compute_instance_spec":"compute_instance_spec",
        "compute_instance_update_spec":"compute_instance_update_spec",
        "compute_disk_spec":"compute_disk_spec",
        "compute_disk_update_spec":"compute_disk_update_spec",
        "compute_filesystem_spec":"compute_filesystem_spec",
        "compute_filesystem_update_spec":"compute_filesystem_update_spec",
        "resource_spec":"resource_spec",
    }
    
class ResourceGroupCost(pb_classes.Message):
    """
    Cost information for a group of resources.
    """
    
    __PB2_CLASS__ = calculator_pb2.ResourceGroupCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.ResourceGroupCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_cost_type__(pb_classes.OneOf):
        name: builtins.str= "cost_type"
        
        def __init__(self, msg: "ResourceGroupCost") -> None:
            super().__init__()
            self._message: "ResourceGroupCost" = msg
    
    class __OneOfClass_cost_type_general__(__OneOfClass_cost_type__):
        field: typing.Literal["general"] = "general"
        
        def __init__(self, msg: "ResourceGroupCost") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "GeneralTotalCost":
            return self._message.general
    
    @builtins.property
    def cost_type(self) -> __OneOfClass_cost_type_general__|None:
        field_name_1: str|None = super().which_field_in_oneof("cost_type")
        match field_name_1:
            case "general":
                return self.__OneOfClass_cost_type_general__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name_1)
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        general: "GeneralTotalCost|calculator_pb2.GeneralTotalCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(general, unset.UnsetType):
            self.general = general
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "general",
            "cost_type",
        ]
    
    @builtins.property
    def general(self) -> "GeneralTotalCost|None":
        """
        Fixed total cost calculation.
        Used when the total cost is deterministic and doesn't vary.
        """
        
        return super()._get_field("general", explicit_presence=True,
        wrap=GeneralTotalCost,
        )
    @general.setter
    def general(self, value: "GeneralTotalCost|calculator_pb2.GeneralTotalCost|None") -> None:
        return super()._set_field("general",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "general":"general",
        "cost_type":"cost_type",
    }
    
class GeneralTotalCost(pb_classes.Message):
    """
    General total cost with a single fixed amount.
    Used for resources with predictable, non-variable pricing.
    """
    
    __PB2_CLASS__ = calculator_pb2.GeneralTotalCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.GeneralTotalCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        total: "CostBreakdown|calculator_pb2.CostBreakdown|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(total, unset.UnsetType):
            self.total = total
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "total",
        ]
    
    @builtins.property
    def total(self) -> "CostBreakdown":
        """
        Cost breakdown including all SKUs and their individual costs.
        """
        
        return super()._get_field("total", explicit_presence=False,
        wrap=CostBreakdown,
        )
    @total.setter
    def total(self, value: "CostBreakdown|calculator_pb2.CostBreakdown|None") -> None:
        return super()._set_field("total",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "total":"total",
    }
    
class GeneralResourceCost(pb_classes.Message):
    """
    General resource cost for single-unit resources.
    Used for resources like compute instances or disks where the unit count is not variable.
    """
    
    __PB2_CLASS__ = calculator_pb2.GeneralResourceCost
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.GeneralResourceCost",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        total: "CostBreakdown|calculator_pb2.CostBreakdown|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(total, unset.UnsetType):
            self.total = total
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "total",
        ]
    
    @builtins.property
    def total(self) -> "CostBreakdown":
        """
        Cost breakdown for the resource including all SKU costs and total cost.
        """
        
        return super()._get_field("total", explicit_presence=False,
        wrap=CostBreakdown,
        )
    @total.setter
    def total(self, value: "CostBreakdown|calculator_pb2.CostBreakdown|None") -> None:
        return super()._set_field("total",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "total":"total",
    }
    
class CostBreakdown(pb_classes.Message):
    """
    Detailed cost breakdown showing individual SKU costs and totals.
    """
    
    __PB2_CLASS__ = calculator_pb2.CostBreakdown
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.CostBreakdown",calculator_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        cost: "builtins.str|None|unset.UnsetType" = unset.Unset,
        cost_rounded: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(cost, unset.UnsetType):
            self.cost = cost
        if not isinstance(cost_rounded, unset.UnsetType):
            self.cost_rounded = cost_rounded
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "cost",
            "cost_rounded",
        ]
    
    @builtins.property
    def cost(self) -> "builtins.str":
        """
        Total cost as a decimal string.
        Represents the sum of all SKU costs with full precision.
        Example: "42.123456789" for precise billing calculations.
        """
        
        return super()._get_field("cost", explicit_presence=False,
        )
    @cost.setter
    def cost(self, value: "builtins.str|None") -> None:
        return super()._set_field("cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def cost_rounded(self) -> "builtins.str":
        """
        Total cost rounded up to 2 decimal places.
        Example: "42.13"
        """
        
        return super()._get_field("cost_rounded", explicit_presence=False,
        )
    @cost_rounded.setter
    def cost_rounded(self, value: "builtins.str|None") -> None:
        return super()._set_field("cost_rounded",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "cost":"cost",
        "cost_rounded":"cost_rounded",
    }
    
# file: nebius/billing/v1alpha1/offer_type.proto
class OfferType(pb_enum.Enum):
    """
    OfferType is a enum that specifies the type of offer.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.billing.v1alpha1.OfferType",offer_type_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    OFFER_TYPE_UNSPECIFIED = 0
    OFFER_TYPE_CONTRACT_PRICE = 1
    """
    Contract price is a special price for SKU.
    """
    

# file: nebius/billing/v1alpha1/calculator_service.proto
class EstimateRequest(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateRequest",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_spec: "ResourceSpec|calculator_pb2.ResourceSpec|None|unset.UnsetType" = unset.Unset,
        offer_types: "abc.Iterable[OfferType]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_spec, unset.UnsetType):
            self.resource_spec = resource_spec
        if not isinstance(offer_types, unset.UnsetType):
            self.offer_types = offer_types
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_spec",
            "offer_types",
        ]
    
    @builtins.property
    def resource_spec(self) -> "ResourceSpec":
        """
        Resource specification for cost estimation.
        Must contain exactly one resource type.
        """
        
        return super()._get_field("resource_spec", explicit_presence=False,
        wrap=ResourceSpec,
        )
    @resource_spec.setter
    def resource_spec(self, value: "ResourceSpec|calculator_pb2.ResourceSpec|None") -> None:
        return super()._set_field("resource_spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def offer_types(self) -> "abc.MutableSequence[OfferType]":
        """
        Type of offers to be applied to the cost estimate.
        """
        
        return super()._get_field("offer_types", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @offer_types.setter
    def offer_types(self, value: "abc.Iterable[OfferType]|None") -> None:
        return super()._set_field("offer_types",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_spec":"resource_spec",
        "offer_types":"offer_types",
    }
    
class EstimateResponse(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateResponse",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        hourly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
        monthly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(hourly_cost, unset.UnsetType):
            self.hourly_cost = hourly_cost
        if not isinstance(monthly_cost, unset.UnsetType):
            self.monthly_cost = monthly_cost
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "hourly_cost",
            "monthly_cost",
        ]
    
    @builtins.property
    def hourly_cost(self) -> "ResourceGroupCost":
        """
        Estimated hourly cost for the resource.
        """
        
        return super()._get_field("hourly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @hourly_cost.setter
    def hourly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("hourly_cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def monthly_cost(self) -> "ResourceGroupCost":
        """
        Estimated monthly cost for the resource.
        Calculated as hourly_cost * 24 * 30 (720 hours) for resources running continuously.
        """
        
        return super()._get_field("monthly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @monthly_cost.setter
    def monthly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("monthly_cost",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "hourly_cost":"hourly_cost",
        "monthly_cost":"monthly_cost",
    }
    
class EstimateBatchRequest(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateBatchRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateBatchRequest",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resource_specs: "abc.Iterable[ResourceSpec]|None|unset.UnsetType" = unset.Unset,
        offer_types: "abc.Iterable[OfferType]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resource_specs, unset.UnsetType):
            self.resource_specs = resource_specs
        if not isinstance(offer_types, unset.UnsetType):
            self.offer_types = offer_types
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resource_specs",
            "offer_types",
        ]
    
    @builtins.property
    def resource_specs(self) -> "abc.MutableSequence[ResourceSpec]":
        """
        List of resource specifications for cost estimation.
        Each resource will be priced individually and then aggregated into total costs.
        """
        
        return super()._get_field("resource_specs", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(ResourceSpec,None,None),
        )
    @resource_specs.setter
    def resource_specs(self, value: "abc.Iterable[ResourceSpec]|None") -> None:
        return super()._set_field("resource_specs",value,explicit_presence=False,
        )
    
    @builtins.property
    def offer_types(self) -> "abc.MutableSequence[OfferType]":
        """
        Type of offers to be applied to the cost estimate.
        """
        
        return super()._get_field("offer_types", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @offer_types.setter
    def offer_types(self, value: "abc.Iterable[OfferType]|None") -> None:
        return super()._set_field("offer_types",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resource_specs":"resource_specs",
        "offer_types":"offer_types",
    }
    
class EstimateBatchResponse(pb_classes.Message):
    __PB2_CLASS__ = calculator_service_pb2.EstimateBatchResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.billing.v1alpha1.EstimateBatchResponse",calculator_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        hourly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
        monthly_cost: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(hourly_cost, unset.UnsetType):
            self.hourly_cost = hourly_cost
        if not isinstance(monthly_cost, unset.UnsetType):
            self.monthly_cost = monthly_cost
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "hourly_cost",
            "monthly_cost",
        ]
    
    @builtins.property
    def hourly_cost(self) -> "ResourceGroupCost":
        """
        Estimated hourly cost for all resources in the batch.
        """
        
        return super()._get_field("hourly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @hourly_cost.setter
    def hourly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("hourly_cost",value,explicit_presence=False,
        )
    
    @builtins.property
    def monthly_cost(self) -> "ResourceGroupCost":
        """
        Estimated monthly cost for all resources in the batch.
        Calculated as hourly_cost * 24 * 30 (720 hours) for resources running continuously.
        """
        
        return super()._get_field("monthly_cost", explicit_presence=False,
        wrap=ResourceGroupCost,
        )
    @monthly_cost.setter
    def monthly_cost(self, value: "ResourceGroupCost|calculator_pb2.ResourceGroupCost|None") -> None:
        return super()._set_field("monthly_cost",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "hourly_cost":"hourly_cost",
        "monthly_cost":"monthly_cost",
    }
    

class CalculatorServiceClient(client.Client):
    """
    Calculator service for estimating resource costs.
    
    This class provides the client methods for the ``.nebius.billing.v1alpha1.CalculatorService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.billing.v1alpha1.CalculatorService",calculator_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.billing.v1alpha1.CalculatorService"
    
    def estimate(self,
        request: "EstimateRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["EstimateRequest","EstimateResponse"]:
        """
        Estimates prices for a single resource.
        Returns both hourly and monthly cost estimates for the specified resource configuration.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.EstimateRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.EstimateResponse`.
        """
        
        return super().request(
            method="Estimate",
            request=request,
            result_pb2_class=calculator_service_pb2.EstimateResponse,
            result_wrapper=pb_classes.simple_wrapper(EstimateResponse),
            **kwargs,
        )
    
    def estimate_batch(self,
        request: "EstimateBatchRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["EstimateBatchRequest","EstimateBatchResponse"]:
        """
        Estimates prices for multiple resources.
        Returns aggregated hourly and monthly cost estimates for all specified resources.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.billing.v1alpha1.EstimateBatchRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.billing.v1alpha1.EstimateBatchResponse`.
        """
        
        return super().request(
            method="EstimateBatch",
            request=request,
            result_pb2_class=calculator_service_pb2.EstimateBatchResponse,
            result_wrapper=pb_classes.simple_wrapper(EstimateBatchResponse),
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "ResourceSpec",
    "ResourceGroupCost",
    "GeneralTotalCost",
    "GeneralResourceCost",
    "CostBreakdown",
    "OfferType",
    "EstimateRequest",
    "EstimateResponse",
    "EstimateBatchRequest",
    "EstimateBatchResponse",
    "CalculatorServiceClient",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as nebius_dot_common_dot_v1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1 import image_pb2 as nebius_dot_compute_dot_v1_dot_image__pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as nebius_dot_compute_dot_v1_dot_operation__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%nebius/compute/v1/image_service.proto\x12\x11nebius.compute.v1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a(nebius/common/v1/operation_service.proto\x1a\x1dnebius/compute/v1/image.proto\x1a)nebius/compute/v1/operation_service.proto\"!\n\x0fGetImageRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"_\n\x1dGetImageLatestByFamilyRequest\x12!\n\x0cimage_family\x18\x01 \x01(\tR\x0bimageFamily\x12\x1b\n\tparent_id\x18\x02 \x01(\tR\x08parentId\"\xd6\x01\n\x11ListImagesRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12h\n\x06\x66ilter\x18\x04 \x01(\tBP\x18\x01\xd2JK\n\n2025-06-16\x12=it is not implemented, filtering could be done on client sideR\x06\x66ilter\"l\n\x12ListImagesResponse\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x18.nebius.compute.v1.ImageR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xd6\x03\n\x0cImageService\x12\x43\n\x03Get\x12\".nebius.compute.v1.GetImageRequest\x1a\x18.nebius.compute.v1.Image\x12I\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x18.nebius.compute.v1.Image\x12_\n\x11GetLatestByFamily\x12\x30.nebius.compute.v1.GetImageLatestByFamilyRequest\x1a\x18.nebius.compute.v1.Image\x12S\n\x04List\x12$.nebius.compute.v1.ListImagesRequest\x1a%.nebius.compute.v1.ListImagesResponse\x12t\n\x16ListOperationsByParent\x12\x30.nebius.compute.v1.ListOperationsByParentRequest\x1a(.nebius.common.v1.ListOperationsResponse\x1a\n\xbaJ\x07\x63omputeB`\n\x18\x61i.nebius.pub.compute.v1B\x11ImageServiceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.image_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\021ImageServiceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _LISTIMAGESREQUEST.fields_by_name['filter']._options = None
  _LISTIMAGESREQUEST.fields_by_name['filter']._serialized_options = b'\030\001\322JK\n\n2025-06-16\022=it is not implemented, filtering could be done on client side'
  _IMAGESERVICE._options = None
  _IMAGESERVICE._serialized_options = b'\272J\007compute'
  _globals['_GETIMAGEREQUEST']._serialized_start=235
  _globals['_GETIMAGEREQUEST']._serialized_end=268
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_start=270
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_end=365
  _globals['_LISTIMAGESREQUEST']._serialized_start=368
  _globals['_LISTIMAGESREQUEST']._serialized_end=582
  _globals['_LISTIMAGESRESPONSE']._serialized_start=584
  _globals['_LISTIMAGESRESPONSE']._serialized_end=692
  _globals['_IMAGESERVICE']._serialized_start=695
  _globals['_IMAGESERVICE']._serialized_end=1165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1alpha1/instance_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/mk8s/v1alpha1/instance_template.proto\x12\x14nebius.mk8s.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\"\xc6\x03\n\x08\x44iskSpec\x12-\n\nsize_bytes\x18\x01 \x01(\x03\x42\x0c\xbaH\t\"\x07(\x80\x80\x80\x80\x80\x02H\x00R\tsizeBytes\x12\x33\n\x0esize_kibibytes\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05(\x80\x80\x80 H\x00R\rsizeKibibytes\x12\x32\n\x0esize_mebibytes\x18\x03 \x01(\x03\x42\t\xbaH\x06\"\x04(\x80\x80\x04H\x00R\rsizeMebibytes\x12\x30\n\x0esize_gibibytes\x18\x04 \x01(\x03\x42\x07\xbaH\x04\"\x02(@H\x00R\rsizeGibibytes\x12(\n\x10\x62lock_size_bytes\x18\x05 \x01(\x03R\x0e\x62lockSizeBytes\x12\x41\n\x04type\x18\x06 \x01(\x0e\x32\'.nebius.mk8s.v1alpha1.DiskSpec.DiskTypeB\x04\xbaJ\x01\x07R\x04type\"t\n\x08\x44iskType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bNETWORK_SSD\x10\x01\x12\x0f\n\x0bNETWORK_HDD\x10\x02\x12\x15\n\x11NETWORK_SSD_IO_M3\x10\x03\x12\x1e\n\x1aNETWORK_SSD_NON_REPLICATED\x10\x04\x42\r\n\x04size\x12\x05\xbaH\x02\x08\x01\"\\\n\rResourcesSpec\x12\"\n\x08platform\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08platform\x12\x18\n\x06preset\x18\x02 \x01(\tH\x00R\x06presetB\r\n\x04size\x12\x05\xbaH\x02\x08\x01\x42\x7f\n\x1b\x61i.nebius.pub.mk8s.v1alpha1B\x15InstanceTemplateProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\xb8\x01\x01\xd2J\x0f\x12\rmigrate to v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1alpha1.instance_template_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mk8s.v1alpha1B\025InstanceTemplateProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\270\001\001\322J\017\022\rmigrate to v1'
  _DISKSPEC.oneofs_by_name['size']._options = None
  _DISKSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _DISKSPEC.fields_by_name['size_bytes']._options = None
  _DISKSPEC.fields_by_name['size_bytes']._serialized_options = b'\272H\t\"\007(\200\200\200\200\200\002'
  _DISKSPEC.fields_by_name['size_kibibytes']._options = None
  _DISKSPEC.fields_by_name['size_kibibytes']._serialized_options = b'\272H\007\"\005(\200\200\200 '
  _DISKSPEC.fields_by_name['size_mebibytes']._options = None
  _DISKSPEC.fields_by_name['size_mebibytes']._serialized_options = b'\272H\006\"\004(\200\200\004'
  _DISKSPEC.fields_by_name['size_gibibytes']._options = None
  _DISKSPEC.fields_by_name['size_gibibytes']._serialized_options = b'\272H\004\"\002(@'
  _DISKSPEC.fields_by_name['type']._options = None
  _DISKSPEC.fields_by_name['type']._serialized_options = b'\272J\001\007'
  _RESOURCESSPEC.oneofs_by_name['size']._options = None
  _RESOURCESSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _RESOURCESSPEC.fields_by_name['platform']._options = None
  _RESOURCESSPEC.fields_by_name['platform']._serialized_options = b'\272H\003\310\001\001'
  _globals['_DISKSPEC']._serialized_start=126
  _globals['_DISKSPEC']._serialized_end=580
  _globals['_DISKSPEC_DISKTYPE']._serialized_start=449
  _globals['_DISKSPEC_DISKTYPE']._serialized_end=565
  _globals['_RESOURCESSPEC']._serialized_start=582
  _globals['_RESOURCESSPEC']._serialized_end=674
# @@protoc_insertion_point(module_scope)



from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.dns.v1 import record_pb2 as _record_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/allocation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.vpc.v1alpha1 import pool_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/vpc/v1alpha1/allocation.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1enebius/vpc/v1alpha1/pool.proto\"\xc4\x01\n\nAllocation\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x37\n\x04spec\x18\x02 \x01(\x0b\x32#.nebius.vpc.v1alpha1.AllocationSpecR\x04spec\x12=\n\x06status\x18\x03 \x01(\x0b\x32%.nebius.vpc.v1alpha1.AllocationStatusR\x06status\"\xd5\x01\n\x0e\x41llocationSpec\x12Y\n\x0cipv4_private\x18\x01 \x01(\x0b\x32..nebius.vpc.v1alpha1.IPv4PrivateAllocationSpecB\x04\xbaJ\x01\x06H\x00R\x0bipv4Private\x12V\n\x0bipv4_public\x18\x02 \x01(\x0b\x32-.nebius.vpc.v1alpha1.IPv4PublicAllocationSpecB\x04\xbaJ\x01\x06H\x00R\nipv4PublicB\x10\n\x07ip_spec\x12\x05\xbaH\x02\x08\x01\"\xbf\x02\n\x19IPv4PrivateAllocationSpec\x12\xcc\x01\n\x04\x63idr\x18\x01 \x01(\tB\xb7\x01\xbaH\xaf\x01\xba\x01\xab\x01\n\x11string.valid_cidr\x12.value must be a valid IP address, CIDR or mask\x1a\x66this == \'\' || this.matches(\'^/([0-9]|[1-2][0-9]|3[0-2])$\') || this.isIp(4) || this.isIpPrefix(4, true)\xbaJ\x01\x02R\x04\x63idr\x12#\n\tsubnet_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x02H\x00R\x08subnetId\x12\x1f\n\x07pool_id\x18\x03 \x01(\tB\x04\xbaJ\x01\x02H\x00R\x06poolIdB\r\n\x04pool\x12\x05\xbaH\x02\x08\x01\"\x88\x02\n\x18IPv4PublicAllocationSpec\x12\xcc\x01\n\x04\x63idr\x18\x01 \x01(\tB\xb7\x01\xbaH\xaf\x01\xba\x01\xab\x01\n\x11string.valid_cidr\x12.value must be a valid IP address, CIDR or mask\x1a\x66this == \'\' || this.matches(\'^/([0-9]|[1-2][0-9]|3[0-2])$\') || this.isIp(4) || this.isIpPrefix(4, true)\xbaJ\x01\x02R\x04\x63idr\x12\x1d\n\x07pool_id\x18\x02 \x01(\tB\x04\xbaJ\x01\x02R\x06poolId\"\xc9\x02\n\x10\x41llocationStatus\x12\x41\n\x05state\x18\x01 \x01(\x0e\x32+.nebius.vpc.v1alpha1.AllocationStatus.StateR\x05state\x12@\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32&.nebius.vpc.v1alpha1.AllocationDetailsR\x07\x64\x65tails\x12?\n\nassignment\x18\x03 \x01(\x0b\x32\x1f.nebius.vpc.v1alpha1.AssignmentR\nassignment\x12\x16\n\x06static\x18\x04 \x01(\x08R\x06static\"W\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\r\n\tALLOCATED\x10\x02\x12\x0c\n\x08\x41SSIGNED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"\x8d\x01\n\x11\x41llocationDetails\x12%\n\x0e\x61llocated_cidr\x18\x01 \x01(\tR\rallocatedCidr\x12\x17\n\x07pool_id\x18\x02 \x01(\tR\x06poolId\x12\x38\n\x07version\x18\x04 \x01(\x0e\x32\x1e.nebius.vpc.v1alpha1.IpVersionR\x07version\"\xc8\x01\n\nAssignment\x12^\n\x11network_interface\x18\x01 \x01(\x0b\x32/.nebius.vpc.v1alpha1.NetworkInterfaceAssignmentH\x00R\x10networkInterface\x12R\n\rload_balancer\x18\x02 \x01(\x0b\x32+.nebius.vpc.v1alpha1.LoadBalancerAssignmentH\x00R\x0cloadBalancerB\x06\n\x04type\"Q\n\x1aNetworkInterfaceAssignment\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"(\n\x16LoadBalancerAssignment\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02idBb\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\x0f\x41llocationProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.allocation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\017AllocationProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _ALLOCATIONSPEC.oneofs_by_name['ip_spec']._options = None
  _ALLOCATIONSPEC.oneofs_by_name['ip_spec']._serialized_options = b'\272H\002\010\001'
  _ALLOCATIONSPEC.fields_by_name['ipv4_private']._options = None
  _ALLOCATIONSPEC.fields_by_name['ipv4_private']._serialized_options = b'\272J\001\006'
  _ALLOCATIONSPEC.fields_by_name['ipv4_public']._options = None
  _ALLOCATIONSPEC.fields_by_name['ipv4_public']._serialized_options = b'\272J\001\006'
  _IPV4PRIVATEALLOCATIONSPEC.oneofs_by_name['pool']._options = None
  _IPV4PRIVATEALLOCATIONSPEC.oneofs_by_name['pool']._serialized_options = b'\272H\002\010\001'
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['cidr']._options = None
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['cidr']._serialized_options = b'\272H\257\001\272\001\253\001\n\021string.valid_cidr\022.value must be a valid IP address, CIDR or mask\032fthis == \'\' || this.matches(\'^/([0-9]|[1-2][0-9]|3[0-2])$\') || this.isIp(4) || this.isIpPrefix(4, true)\272J\001\002'
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['subnet_id']._options = None
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['subnet_id']._serialized_options = b'\272J\001\002'
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['pool_id']._options = None
  _IPV4PRIVATEALLOCATIONSPEC.fields_by_name['pool_id']._serialized_options = b'\272J\001\002'
  _IPV4PUBLICALLOCATIONSPEC.fields_by_name['cidr']._options = None
  _IPV4PUBLICALLOCATIONSPEC.fields_by_name['cidr']._serialized_options = b'\272H\257\001\272\001\253\001\n\021string.valid_cidr\022.value must be a valid IP address, CIDR or mask\032fthis == \'\' || this.matches(\'^/([0-9]|[1-2][0-9]|3[0-2])$\') || this.isIp(4) || this.isIpPrefix(4, true)\272J\001\002'
  _IPV4PUBLICALLOCATIONSPEC.fields_by_name['pool_id']._options = None
  _IPV4PUBLICALLOCATIONSPEC.fields_by_name['pool_id']._serialized_options = b'\272J\001\002'
  _globals['_ALLOCATION']._serialized_start=182
  _globals['_ALLOCATION']._serialized_end=378
  _globals['_ALLOCATIONSPEC']._serialized_start=381
  _globals['_ALLOCATIONSPEC']._serialized_end=594
  _globals['_IPV4PRIVATEALLOCATIONSPEC']._serialized_start=597
  _globals['_IPV4PRIVATEALLOCATIONSPEC']._serialized_end=916
  _globals['_IPV4PUBLICALLOCATIONSPEC']._serialized_start=919
  _globals['_IPV4PUBLICALLOCATIONSPEC']._serialized_end=1183
  _globals['_ALLOCATIONSTATUS']._serialized_start=1186
  _globals['_ALLOCATIONSTATUS']._serialized_end=1515
  _globals['_ALLOCATIONSTATUS_STATE']._serialized_start=1428
  _globals['_ALLOCATIONSTATUS_STATE']._serialized_end=1515
  _globals['_ALLOCATIONDETAILS']._serialized_start=1518
  _globals['_ALLOCATIONDETAILS']._serialized_end=1659
  _globals['_ASSIGNMENT']._serialized_start=1662
  _globals['_ASSIGNMENT']._serialized_end=1862
  _globals['_NETWORKINTERFACEASSIGNMENT']._serialized_start=1864
  _globals['_NETWORKINTERFACEASSIGNMENT']._serialized_end=1945
  _globals['_LOADBALANCERASSIGNMENT']._serialized_start=1947
  _globals['_LOADBALANCERASSIGNMENT']._serialized_end=1987
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v2/project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnebius/iam/v2/project.proto\x12\rnebius.iam.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xc5\x01\n\x07Project\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32\x1a.nebius.iam.v2.ProjectSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12:\n\x06status\x18\x03 \x01(\x0b\x32\x1c.nebius.iam.v2.ProjectStatusB\x04\xbaJ\x01\x05R\x06status\"%\n\x0bProjectSpec\x12\x16\n\x06region\x18\x01 \x01(\tR\x06region\"\xe4\x01\n\rProjectStatus\x12N\n\rproject_state\x18\x01 \x01(\x0e\x32).nebius.iam.v2.ProjectStatus.ProjectStateR\x0cprojectState\"\x82\x01\n\x0cProjectState\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0b\n\x07PURGING\x10\x03\x12\x0b\n\x07\x43REATED\x10\x04\x12\x0e\n\nACTIVATING\x10\x05\x12\x0b\n\x07PARKING\x10\x06\x12\n\n\x06PARKED\x10\x07\x42S\n\x14\x61i.nebius.pub.iam.v2B\x0cProjectProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v2.project_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v2B\014ProjectProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v2'
  _PROJECT.fields_by_name['metadata']._options = None
  _PROJECT.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _PROJECT.fields_by_name['spec']._options = None
  _PROJECT.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _PROJECT.fields_by_name['status']._options = None
  _PROJECT.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _globals['_PROJECT']._serialized_start=135
  _globals['_PROJECT']._serialized_end=332
  _globals['_PROJECTSPEC']._serialized_start=334
  _globals['_PROJECTSPEC']._serialized_end=371
  _globals['_PROJECTSTATUS']._serialized_start=374
  _globals['_PROJECTSTATUS']._serialized_end=602
  _globals['_PROJECTSTATUS_PROJECTSTATE']._serialized_start=472
  _globals['_PROJECTSTATUS_PROJECTSTATE']._serialized_end=602
# @@protoc_insertion_point(module_scope)



from nebius.api.nebius.storage.v1 import base_pb2 as _base_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CurrentBucketCounters(_message.Message):
    __slots__ = ["simple_objects_quantity", "simple_objects_size", "multipart_objects_quantity", "multipart_objects_size", "multipart_uploads_quantity", "inflight_parts_quantity", "inflight_parts_size"]
    SIMPLE_OBJECTS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_OBJECTS_SIZE_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_OBJECTS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_OBJECTS_SIZE_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_UPLOADS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    INFLIGHT_PARTS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    INFLIGHT_PARTS_SIZE_FIELD_NUMBER: _ClassVar[int]
    simple_objects_quantity: int
    simple_objects_size: int
    multipart_objects_quantity: int
    multipart_objects_size: int
    multipart_uploads_quantity: int
    inflight_parts_quantity: int
    inflight_parts_size: int
    def __init__(self, simple_objects_quantity: _Optional[int] = ..., simple_objects_size: _Optional[int] = ..., multipart_objects_quantity: _Optional[int] = ..., multipart_objects_size: _Optional[int] = ..., multipart_uploads_quantity: _Optional[int] = ..., inflight_parts_quantity: _Optional[int] = ..., inflight_parts_size: _Optional[int] = ...) -> None: ...

class NonCurrentBucketCounters(_message.Message):
    __slots__ = ["simple_objects_quantity", "simple_objects_size", "multipart_objects_quantity", "multipart_objects_size"]
    SIMPLE_OBJECTS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    SIMPLE_OBJECTS_SIZE_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_OBJECTS_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    MULTIPART_OBJECTS_SIZE_FIELD_NUMBER: _ClassVar[int]
    simple_objects_quantity: int
    simple_objects_size: int
    multipart_objects_quantity: int
    multipart_objects_size: int
    def __init__(self, simple_objects_quantity: _Optional[int] = ..., simple_objects_size: _Optional[int] = ..., multipart_objects_quantity: _Optional[int] = ..., multipart_objects_size: _Optional[int] = ...) -> None: ...

class BucketCounters(_message.Message):
    __slots__ = ["storage_class", "counters", "non_current_counters"]
    STORAGE_CLASS_FIELD_NUMBER: _ClassVar[int]
    COUNTERS_FIELD_NUMBER: _ClassVar[int]
    NON_CURRENT_COUNTERS_FIELD_NUMBER: _ClassVar[int]
    storage_class: _base_pb2.StorageClass
    counters: CurrentBucketCounters
    non_current_counters: NonCurrentBucketCounters
    def __init__(self, storage_class: _Optional[_Union[_base_pb2.StorageClass, str]] = ..., counters: _Optional[_Union[CurrentBucketCounters, _Mapping]] = ..., non_current_counters: _Optional[_Union[NonCurrentBucketCounters, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import group_pb2 as nebius_dot_iam_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/iam/v1/group_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x19nebius/iam/v1/group.proto\"\x82\x01\n\x12\x43reateGroupRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.iam.v1.GroupSpecR\x04spec\")\n\x0fGetGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"X\n\x15GetGroupByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x9f\x01\n\x11ListGroupsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12 \n\tpage_size\x18\x02 \x01(\x03H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilterB\x0c\n\n_page_size\"h\n\x12ListGroupsResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.iam.v1.GroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\",\n\x12\x44\x65leteGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x82\x01\n\x12UpdateGroupRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.iam.v1.GroupSpecR\x04spec2\xcb\x03\n\x0cGroupService\x12H\n\x06\x43reate\x12!.nebius.iam.v1.CreateGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12;\n\x03Get\x12\x1e.nebius.iam.v1.GetGroupRequest\x1a\x14.nebius.iam.v1.Group\x12G\n\tGetByName\x12$.nebius.iam.v1.GetGroupByNameRequest\x1a\x14.nebius.iam.v1.Group\x12K\n\x04List\x12 .nebius.iam.v1.ListGroupsRequest\x1a!.nebius.iam.v1.ListGroupsResponse\x12H\n\x06\x44\x65lete\x12!.nebius.iam.v1.DeleteGroupRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06Update\x12!.nebius.iam.v1.UpdateGroupRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamBX\n\x14\x61i.nebius.pub.iam.v1B\x11GroupServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\021GroupServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETGROUPREQUEST.fields_by_name['id']._options = None
  _GETGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETGROUPBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETGROUPBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETGROUPBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEGROUPREQUEST.fields_by_name['id']._options = None
  _DELETEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GROUPSERVICE._options = None
  _GROUPSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEGROUPREQUEST']._serialized_start=202
  _globals['_CREATEGROUPREQUEST']._serialized_end=332
  _globals['_GETGROUPREQUEST']._serialized_start=334
  _globals['_GETGROUPREQUEST']._serialized_end=375
  _globals['_GETGROUPBYNAMEREQUEST']._serialized_start=377
  _globals['_GETGROUPBYNAMEREQUEST']._serialized_end=465
  _globals['_LISTGROUPSREQUEST']._serialized_start=468
  _globals['_LISTGROUPSREQUEST']._serialized_end=627
  _globals['_LISTGROUPSRESPONSE']._serialized_start=629
  _globals['_LISTGROUPSRESPONSE']._serialized_end=733
  _globals['_DELETEGROUPREQUEST']._serialized_start=735
  _globals['_DELETEGROUPREQUEST']._serialized_end=779
  _globals['_UPDATEGROUPREQUEST']._serialized_start=782
  _globals['_UPDATEGROUPREQUEST']._serialized_end=912
  _globals['_GROUPSERVICE']._serialized_start=915
  _globals['_GROUPSERVICE']._serialized_end=1374
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProgressData(_message.Message):
    __slots__ = ["problems"]
    PROBLEMS_FIELD_NUMBER: _ClassVar[int]
    problems: _containers.RepeatedCompositeFieldContainer[Problem]
    def __init__(self, problems: _Optional[_Iterable[_Union[Problem, _Mapping]]] = ...) -> None: ...

class Problem(_message.Message):
    __slots__ = ["stage", "message"]
    STAGE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    stage: str
    message: str
    def __init__(self, stage: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/maintenance/v1alpha1/maintenance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.maintenance.v1alpha1 import maintenance_pb2 as nebius_dot_maintenance_dot_v1alpha1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/maintenance/v1alpha1/maintenance_service.proto\x12\x1bnebius.maintenance.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a-nebius/maintenance/v1alpha1/maintenance.proto\">\n\x17ListMaintenancesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\"Z\n\x18ListMaintenancesResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.maintenance.v1alpha1.MaintenanceR\x05items\"/\n\x15GetMaintenanceRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xfa\x01\n\x18UpdateMaintenanceRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12@\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.maintenance.v1alpha1.MaintenanceSpecR\x04spec:T\xbaHQ\x1aO\n\x1bupdate_maintenance.metadata\x12\x19\'metadata\' must have \'id\'\x1a\x15has(this.metadata.id)\"g\n\x19UpdateMaintenanceResponse\x12J\n\x0bmaintenance\x18\x01 \x01(\x0b\x32(.nebius.maintenance.v1alpha1.MaintenanceR\x0bmaintenance2\xfb\x02\n\x12MaintenanceService\x12\x63\n\x03Get\x12\x32.nebius.maintenance.v1alpha1.GetMaintenanceRequest\x1a(.nebius.maintenance.v1alpha1.Maintenance\x12s\n\x04List\x12\x34.nebius.maintenance.v1alpha1.ListMaintenancesRequest\x1a\x35.nebius.maintenance.v1alpha1.ListMaintenancesResponse\x12w\n\x06Update\x12\x35.nebius.maintenance.v1alpha1.UpdateMaintenanceRequest\x1a\x36.nebius.maintenance.v1alpha1.UpdateMaintenanceResponse\x1a\x12\xbaJ\x0fmaintenance.mspBz\n\"ai.nebius.pub.maintenance.v1alpha1B\x17MaintenanceServiceProtoP\x01Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.maintenance.v1alpha1.maintenance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"ai.nebius.pub.maintenance.v1alpha1B\027MaintenanceServiceProtoP\001Z9github.com/nebius/gosdk/proto/nebius/maintenance/v1alpha1'
  _LISTMAINTENANCESREQUEST.fields_by_name['parent_id']._options = None
  _LISTMAINTENANCESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETMAINTENANCEREQUEST.fields_by_name['id']._options = None
  _GETMAINTENANCEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEMAINTENANCEREQUEST.fields_by_name['metadata']._options = None
  _UPDATEMAINTENANCEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEMAINTENANCEREQUEST._options = None
  _UPDATEMAINTENANCEREQUEST._serialized_options = b'\272HQ\032O\n\033update_maintenance.metadata\022\031\'metadata\' must have \'id\'\032\025has(this.metadata.id)'
  _MAINTENANCESERVICE._options = None
  _MAINTENANCESERVICE._serialized_options = b'\272J\017maintenance.msp'
  _globals['_LISTMAINTENANCESREQUEST']._serialized_start=221
  _globals['_LISTMAINTENANCESREQUEST']._serialized_end=283
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_start=285
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_end=375
  _globals['_GETMAINTENANCEREQUEST']._serialized_start=377
  _globals['_GETMAINTENANCEREQUEST']._serialized_end=424
  _globals['_UPDATEMAINTENANCEREQUEST']._serialized_start=427
  _globals['_UPDATEMAINTENANCEREQUEST']._serialized_end=677
  _globals['_UPDATEMAINTENANCERESPONSE']._serialized_start=679
  _globals['_UPDATEMAINTENANCERESPONSE']._serialized_end=782
  _globals['_MAINTENANCESERVICE']._serialized_start=785
  _globals['_MAINTENANCESERVICE']._serialized_end=1164
# @@protoc_insertion_point(module_scope)



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.msp.v1alpha1.resource``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.api.nebius.msp.v1alpha1.resource.template_pb2 as template_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.unset as unset
#@ local imports here @#

# file: nebius/msp/v1alpha1/resource/template.proto
class Template(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.Template
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.Template",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        status: "TemplateStatus|template_pb2.TemplateStatus|None|unset.UnsetType" = unset.Unset,
        spec: "TemplateSpec|template_pb2.TemplateSpec|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(status, unset.UnsetType):
            self.status = status
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "status",
            "spec",
        ]
    
    @builtins.property
    def status(self) -> "TemplateStatus":
        return super()._get_field("status", explicit_presence=False,
        wrap=TemplateStatus,
        )
    @status.setter
    def status(self, value: "TemplateStatus|template_pb2.TemplateStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "TemplateSpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=TemplateSpec,
        )
    @spec.setter
    def spec(self, value: "TemplateSpec|template_pb2.TemplateSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "status":"status",
        "spec":"spec",
    }
    
class TemplateStatus(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.TemplateStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.TemplateStatus",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        preset_details: "PresetDetails|template_pb2.PresetDetails|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(preset_details, unset.UnsetType):
            self.preset_details = preset_details
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "preset_details",
        ]
    
    @builtins.property
    def preset_details(self) -> "PresetDetails":
        return super()._get_field("preset_details", explicit_presence=False,
        wrap=PresetDetails,
        )
    @preset_details.setter
    def preset_details(self, value: "PresetDetails|template_pb2.PresetDetails|None") -> None:
        return super()._set_field("preset_details",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "preset_details":"preset_details",
    }
    
class TemplateSpec(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.TemplateSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.TemplateSpec",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        resources: "ResourcesSpec|template_pb2.ResourcesSpec|None|unset.UnsetType" = unset.Unset,
        hosts: "Host|template_pb2.Host|None|unset.UnsetType" = unset.Unset,
        disk: "Disk|template_pb2.Disk|None|unset.UnsetType" = unset.Unset,
        role: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(resources, unset.UnsetType):
            self.resources = resources
        if not isinstance(hosts, unset.UnsetType):
            self.hosts = hosts
        if not isinstance(disk, unset.UnsetType):
            self.disk = disk
        if not isinstance(role, unset.UnsetType):
            self.role = role
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "resources",
            "hosts",
            "disk",
            "role",
        ]
    
    @builtins.property
    def resources(self) -> "ResourcesSpec":
        return super()._get_field("resources", explicit_presence=False,
        wrap=ResourcesSpec,
        )
    @resources.setter
    def resources(self, value: "ResourcesSpec|template_pb2.ResourcesSpec|None") -> None:
        return super()._set_field("resources",value,explicit_presence=False,
        )
    
    @builtins.property
    def hosts(self) -> "Host":
        return super()._get_field("hosts", explicit_presence=False,
        wrap=Host,
        )
    @hosts.setter
    def hosts(self, value: "Host|template_pb2.Host|None") -> None:
        return super()._set_field("hosts",value,explicit_presence=False,
        )
    
    @builtins.property
    def disk(self) -> "Disk":
        return super()._get_field("disk", explicit_presence=False,
        wrap=Disk,
        )
    @disk.setter
    def disk(self, value: "Disk|template_pb2.Disk|None") -> None:
        return super()._set_field("disk",value,explicit_presence=False,
        )
    
    @builtins.property
    def role(self) -> "builtins.str":
        return super()._get_field("role", explicit_presence=False,
        )
    @role.setter
    def role(self, value: "builtins.str|None") -> None:
        return super()._set_field("role",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "resources":"resources",
        "hosts":"hosts",
        "disk":"disk",
        "role":"role",
    }
    
class ResourcesSpec(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.ResourcesSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.ResourcesSpec",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        platform: "builtins.str|None|unset.UnsetType" = unset.Unset,
        preset: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(platform, unset.UnsetType):
            self.platform = platform
        if not isinstance(preset, unset.UnsetType):
            self.preset = preset
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "platform",
            "preset",
        ]
    
    @builtins.property
    def platform(self) -> "builtins.str":
        return super()._get_field("platform", explicit_presence=False,
        )
    @platform.setter
    def platform(self, value: "builtins.str|None") -> None:
        return super()._set_field("platform",value,explicit_presence=False,
        )
    
    @builtins.property
    def preset(self) -> "builtins.str":
        return super()._get_field("preset", explicit_presence=False,
        )
    @preset.setter
    def preset(self, value: "builtins.str|None") -> None:
        return super()._set_field("preset",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "platform":"platform",
        "preset":"preset",
    }
    
class PresetDetails(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.PresetDetails
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.PresetDetails",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        cpu_count: "builtins.int|None|unset.UnsetType" = unset.Unset,
        memory_gibibytes: "builtins.int|None|unset.UnsetType" = unset.Unset,
        gpu_count: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(cpu_count, unset.UnsetType):
            self.cpu_count = cpu_count
        if not isinstance(memory_gibibytes, unset.UnsetType):
            self.memory_gibibytes = memory_gibibytes
        if not isinstance(gpu_count, unset.UnsetType):
            self.gpu_count = gpu_count
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "cpu_count",
            "memory_gibibytes",
            "gpu_count",
        ]
    
    @builtins.property
    def cpu_count(self) -> "builtins.int":
        return super()._get_field("cpu_count", explicit_presence=False,
        )
    @cpu_count.setter
    def cpu_count(self, value: "builtins.int|None") -> None:
        return super()._set_field("cpu_count",value,explicit_presence=False,
        )
    
    @builtins.property
    def memory_gibibytes(self) -> "builtins.int":
        return super()._get_field("memory_gibibytes", explicit_presence=False,
        )
    @memory_gibibytes.setter
    def memory_gibibytes(self, value: "builtins.int|None") -> None:
        return super()._set_field("memory_gibibytes",value,explicit_presence=False,
        )
    
    @builtins.property
    def gpu_count(self) -> "builtins.int":
        return super()._get_field("gpu_count", explicit_presence=False,
        )
    @gpu_count.setter
    def gpu_count(self, value: "builtins.int|None") -> None:
        return super()._set_field("gpu_count",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "cpu_count":"cpu_count",
        "memory_gibibytes":"memory_gibibytes",
        "gpu_count":"gpu_count",
    }
    
class Range(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.Range
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.Range",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        min: "builtins.int|None|unset.UnsetType" = unset.Unset,
        max: "builtins.int|None|unset.UnsetType" = unset.Unset,
        step: "builtins.int|None|unset.UnsetType" = unset.Unset,
        value: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(min, unset.UnsetType):
            self.min = min
        if not isinstance(max, unset.UnsetType):
            self.max = max
        if not isinstance(step, unset.UnsetType):
            self.step = step
        if not isinstance(value, unset.UnsetType):
            self.value = value
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "min",
            "max",
            "step",
            "value",
        ]
    
    @builtins.property
    def min(self) -> "builtins.int":
        return super()._get_field("min", explicit_presence=False,
        )
    @min.setter
    def min(self, value: "builtins.int|None") -> None:
        return super()._set_field("min",value,explicit_presence=False,
        )
    
    @builtins.property
    def max(self) -> "builtins.int":
        return super()._get_field("max", explicit_presence=False,
        )
    @max.setter
    def max(self, value: "builtins.int|None") -> None:
        return super()._set_field("max",value,explicit_presence=False,
        )
    
    @builtins.property
    def step(self) -> "builtins.int":
        """
        step 0 is no step validation
        """
        
        return super()._get_field("step", explicit_presence=False,
        )
    @step.setter
    def step(self, value: "builtins.int|None") -> None:
        return super()._set_field("step",value,explicit_presence=False,
        )
    
    @builtins.property
    def value(self) -> "builtins.int":
        return super()._get_field("value", explicit_presence=False,
        )
    @value.setter
    def value(self, value: "builtins.int|None") -> None:
        return super()._set_field("value",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "min":"min",
        "max":"max",
        "step":"step",
        "value":"value",
    }
    
class Disk(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.Disk
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.Disk",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        type: "builtins.str|None|unset.UnsetType" = unset.Unset,
        size_gibibytes: "Range|template_pb2.Range|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(type, unset.UnsetType):
            self.type = type
        if not isinstance(size_gibibytes, unset.UnsetType):
            self.size_gibibytes = size_gibibytes
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "type",
            "size_gibibytes",
        ]
    
    @builtins.property
    def type(self) -> "builtins.str":
        return super()._get_field("type", explicit_presence=False,
        )
    @type.setter
    def type(self, value: "builtins.str|None") -> None:
        return super()._set_field("type",value,explicit_presence=False,
        )
    
    @builtins.property
    def size_gibibytes(self) -> "Range":
        return super()._get_field("size_gibibytes", explicit_presence=False,
        wrap=Range,
        )
    @size_gibibytes.setter
    def size_gibibytes(self, value: "Range|template_pb2.Range|None") -> None:
        return super()._set_field("size_gibibytes",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "type":"type",
        "size_gibibytes":"size_gibibytes",
    }
    
class DiskSpec(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.DiskSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.DiskSpec",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        type: "builtins.str|None|unset.UnsetType" = unset.Unset,
        size_gibibytes: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(type, unset.UnsetType):
            self.type = type
        if not isinstance(size_gibibytes, unset.UnsetType):
            self.size_gibibytes = size_gibibytes
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "type",
            "size_gibibytes",
        ]
    
    @builtins.property
    def type(self) -> "builtins.str":
        return super()._get_field("type", explicit_presence=False,
        )
    @type.setter
    def type(self, value: "builtins.str|None") -> None:
        return super()._set_field("type",value,explicit_presence=False,
        )
    
    @builtins.property
    def size_gibibytes(self) -> "builtins.int":
        return super()._get_field("size_gibibytes", explicit_presence=False,
        )
    @size_gibibytes.setter
    def size_gibibytes(self, value: "builtins.int|None") -> None:
        return super()._set_field("size_gibibytes",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "type":"type",
        "size_gibibytes":"size_gibibytes",
    }
    
class Host(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.Host
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.Host",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        count: "Range|template_pb2.Range|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(count, unset.UnsetType):
            self.count = count
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "count",
        ]
    
    @builtins.property
    def count(self) -> "Range":
        return super()._get_field("count", explicit_presence=False,
        wrap=Range,
        )
    @count.setter
    def count(self, value: "Range|template_pb2.Range|None") -> None:
        return super()._set_field("count",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "count":"count",
    }
    
class HostSpec(pb_classes.Message):
    __PB2_CLASS__ = template_pb2.HostSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.resource.HostSpec",template_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        count: "builtins.int|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(count, unset.UnsetType):
            self.count = count
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "count",
        ]
    
    @builtins.property
    def count(self) -> "builtins.int":
        return super()._get_field("count", explicit_presence=False,
        )
    @count.setter
    def count(self, value: "builtins.int|None") -> None:
        return super()._set_field("count",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "count":"count",
    }
    
__all__ = [
    #@ local import names here @#
    "Template",
    "TemplateStatus",
    "TemplateSpec",
    "ResourcesSpec",
    "PresetDetails",
    "Range",
    "Disk",
    "DiskSpec",
    "Host",
    "HostSpec",
]



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Subject(_message.Message):
    __slots__ = ["service_account_id", "tenant_user_id", "name"]
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    TENANT_USER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    service_account_id: str
    tenant_user_id: str
    name: str
    def __init__(self, service_account_id: _Optional[str] = ..., tenant_user_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...



# type: ignore
import pytest

from nebius.aio import request

request.DEFAULT_AUTH_TIMEOUT = 5.0


@pytest.mark.asyncio
async def test_env_and_token_file_auth(monkeypatch, tmp_path) -> None:
    """Verify EnvBearer and FileBearer via Config + SDK on a compute call."""
    import grpc
    import grpc.aio

    from nebius.aio.cli_config import Config
    from nebius.api.nebius.compute.v1 import (
        DiskServiceClient,
    )
    from nebius.api.nebius.compute.v1 import (
        ListDisksRequest as V1List,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2 import ListDisksResponse
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE
    from nebius.sdk import SDK

    class Compute(DiskServiceServicer):
        def __init__(self, expected_token: str) -> None:
            self.expected_token = expected_token

        async def List(self, request, context):  # noqa: N802 — GRPC method
            headers = dict(context.invocation_metadata() or [])
            auth = headers.get("authorization", "")
            assert self.expected_token in auth
            return ListDisksResponse(items=[])

    async def run_case(expected_token: str, cfg_yaml: str) -> None:
        srv = grpc.aio.server()
        port = srv.add_insecure_port("[::]:0")
        add_DiskServiceServicer_to_server(Compute(expected_token), srv)
        await srv.start()
        try:
            home = (tmp_path / "home_env").resolve()
            monkeypatch.setenv("HOME", str(home))
            cfg_dir = home / ".nebius"
            cfg_dir.mkdir(parents=True, exist_ok=True)
            cfg_file = cfg_dir / "config.yaml"
            cfg_file.write_text(cfg_yaml)

            sdk = SDK(
                domain=f"localhost:{port}",
                options=[(INSECURE, True)],
                config_reader=Config(
                    config_file=cfg_file,
                    profile="test",
                    no_env=True,
                ),
            )
            try:
                client = DiskServiceClient(sdk)
                await client.list(V1List())
            finally:
                await sdk.close()
        finally:
            await srv.stop(0)

    # Env token case: ensure get_token() reads env when no_env not set
    env_home = (tmp_path / "env_home").resolve()
    monkeypatch.setenv("HOME", str(env_home))
    monkeypatch.setenv("NEBIUS_IAM_TOKEN", "envtok")
    cfg_env_dir = env_home / ".nebius"
    cfg_env_dir.mkdir(parents=True, exist_ok=True)
    (cfg_env_dir / "config.yaml").write_text(
        """
default: test
profiles:
  test:
    auth-type: service account
    endpoint: some.endpoint
""".strip()
    )
    sdk1 = SDK(
        domain="localhost:0",
        options=[(INSECURE, True)],
        config_reader=Config(
            config_file=cfg_env_dir / "config.yaml",
            profile="test",
        ),
    )
    try:
        tok = await sdk1.get_token(timeout=2.0, options=None)
        assert tok.token == "envtok"
    finally:
        await sdk1.close()

    # Token-file case
    tok_dir = tmp_path / "tok"
    tok_dir.mkdir(parents=True, exist_ok=True)
    tok_file = tok_dir / "tok.txt"
    tok_file.write_text("filetok\n")
    cfg_yaml_file = f"""
default: test
profiles:
  test:
    token-file: {tok_file}
    endpoint: some.endpoint
""".strip()
    await run_case("filetok", cfg_yaml_file)


@pytest.mark.asyncio
async def test_service_account_variants(monkeypatch, tmp_path) -> None:
    """
    Service account via inline PEM, credentials file,
    and federated credentials file.
    """
    import grpc
    import grpc.aio
    from cryptography.hazmat.primitives import serialization
    from cryptography.hazmat.primitives.asymmetric import rsa

    from nebius.aio.cli_config import Config
    from nebius.api.nebius.compute.v1 import (
        DiskServiceClient,
    )
    from nebius.api.nebius.compute.v1 import (
        ListDisksRequest as V1List,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2 import ListDisksResponse
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_exchange_service_pb2_grpc import (
        TokenExchangeService,
        add_TokenExchangeServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_service_pb2 import CreateTokenResponse
    from nebius.base.options import INSECURE
    from nebius.sdk import SDK

    class Compute(DiskServiceServicer):
        async def List(self, request, context):  # noqa: N802 — GRPC method
            headers = dict(context.invocation_metadata() or [])
            assert "satok" in headers.get("authorization", "")
            return ListDisksResponse(items=[])

    class TokenExchange(TokenExchangeService):
        async def Exchange(self, request, context):  # noqa: N802 — GRPC method
            return CreateTokenResponse(
                access_token="satok", token_type="Bearer", expires_in=3600
            )

    srv = grpc.aio.server()
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(Compute(), srv)
    add_TokenExchangeServiceServicer_to_server(TokenExchange(), srv)
    await srv.start()
    try:
        home = (tmp_path / "sa_home").resolve()
        monkeypatch.setenv("HOME", str(home))
        cfg_dir = home / ".nebius"
        cfg_dir.mkdir(parents=True, exist_ok=True)

        # Generate a test RSA key and PEM in PKCS8 format
        key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
        pem = key.private_bytes(
            encoding=serialization.Encoding.PEM,
            format=serialization.PrivateFormat.PKCS8,
            encryption_algorithm=serialization.NoEncryption(),
        ).decode("utf-8")

        # 1) Inline private key
        pem_block = "\n".join(["      " + ln for ln in pem.strip().splitlines()])
        cfg_inline = (
            "default: test\n"
            "profiles:\n"
            "  test:\n"
            "    auth-type: service account\n"
            "    service-account-id: sa-123\n"
            "    public-key-id: pk-abc\n"
            "    private-key: |-\n" + pem_block + f"\n    endpoint: localhost:{port}\n"
        )
        (cfg_dir / "config.yaml").write_text(cfg_inline)
        sdk = SDK(
            domain=f"localhost:{port}",
            options=[(INSECURE, True)],
            config_reader=Config(
                config_file=cfg_dir / "config.yaml",
                profile="test",
                no_env=True,
            ),
        )
        try:
            client = DiskServiceClient(sdk)
            await client.list(V1List())
        finally:
            await sdk.close()

        # 2) Credentials file path
        import json as _json

        creds_file = cfg_dir / "sa.json"
        creds_file.write_text(
            _json.dumps(
                {
                    "subject-credentials": {
                        "type": "JWT",
                        "alg": "RS256",
                        "private-key": pem,
                        "kid": "pk-abc",
                        "iss": "sa-123",
                        "sub": "sa-123",
                    }
                }
            )
        )
        cfg_creds = f"""
default: test
profiles:
  test:
    auth-type: service account
    service-account-credentials-file-path: {creds_file}
    endpoint: localhost:{port}
""".strip()
        (cfg_dir / "config.yaml").write_text(cfg_creds)
        sdk2 = SDK(
            domain=f"localhost:{port}",
            options=[(INSECURE, True)],
            config_reader=Config(
                config_file=cfg_dir / "config.yaml",
                profile="test",
                no_env=True,
            ),
        )
        try:
            client = DiskServiceClient(sdk2)
            await client.list(V1List())
        finally:
            await sdk2.close()

        # 3) Federated subject credentials file path
        fc_file = cfg_dir / "fc.txt"
        fc_file.write_text("federated-creds")
        cfg_fc = f"""
default: test
profiles:
  test:
    auth-type: service account
    service-account-id: sa-123
    federated-subject-credentials-file-path: {fc_file}
    endpoint: localhost:{port}
""".strip()
        (cfg_dir / "config.yaml").write_text(cfg_fc)
        sdk3 = SDK(
            domain=f"localhost:{port}",
            options=[(INSECURE, True)],
            config_reader=Config(
                config_file=cfg_dir / "config.yaml",
                profile="test",
                no_env=True,
            ),
        )
        try:
            client = DiskServiceClient(sdk3)
            await client.list(V1List())
        finally:
            await sdk3.close()
    finally:
        await srv.stop(0)


@pytest.mark.asyncio
async def test_federation_auth_flow(monkeypatch, tmp_path) -> None:
    """End-to-end federation flow against a local HTTP server, no browser open."""
    import asyncio
    import io
    import socket

    import aiohttp
    import grpc
    import grpc.aio
    from aiohttp import web

    from nebius.aio.cli_config import Config
    from nebius.api.nebius.compute.v1 import (
        DiskServiceClient,
    )
    from nebius.api.nebius.compute.v1 import (
        ListDisksRequest as V1List,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2 import ListDisksResponse
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE
    from nebius.sdk import SDK

    code_value = "authcode"
    token_value = "tok123"

    async def handle_authorize(request: web.Request) -> web.StreamResponse:
        q = request.rel_url.query
        state = q.get("state", "")
        redirect = q.get("redirect_uri", "")
        assert state and redirect
        location = f"{redirect}?code={code_value}&state={state}"
        raise web.HTTPFound(location=location)

    async def handle_token(request: web.Request) -> web.Response:
        data = await request.post()
        if data.get("code") != code_value:
            return web.Response(status=400, text="wrong code")
        return web.json_response({"access_token": token_value, "expires_in": 3600})

    app = web.Application()
    app.router.add_get("/oauth2/authorize", handle_authorize)
    app.router.add_post("/oauth2/token", handle_token)
    runner = web.AppRunner(app)
    await runner.setup()
    sock = socket.socket()
    sock.bind(("127.0.0.1", 0))
    http_port = sock.getsockname()[1]
    sock.close()
    site = web.TCPSite(runner, "127.0.0.1", http_port)
    await site.start()
    try:
        fed_url = f"http://127.0.0.1:{http_port}"

        class Compute(DiskServiceServicer):
            async def List(self, request, context):  # noqa: N802 — GRPC method
                headers = dict(context.invocation_metadata() or [])
                assert token_value in headers.get("authorization", "")
                return ListDisksResponse(items=[])

        srv = grpc.aio.server()
        port = srv.add_insecure_port("[::]:0")
        add_DiskServiceServicer_to_server(Compute(), srv)
        await srv.start()
        try:
            home = (tmp_path / "fed_home").resolve()
            monkeypatch.setenv("HOME", str(home))
            cfg_dir = home / ".nebius"
            cfg_dir.mkdir(parents=True, exist_ok=True)
            cfg_file = cfg_dir / "config.yaml"
            cfg_file.write_text(
                f"""
default: test
profiles:
  test:
    auth-type: federation
    federation-endpoint: {fed_url}
    federation-id: fid-123
    endpoint: localhost:{port}
""".strip()
            )

            out = io.StringIO()
            sdk = SDK(
                domain=f"localhost:{port}",
                options=[(INSECURE, True)],
                config_reader=Config(
                    client_id="client-abc",
                    config_file=cfg_file,
                    profile="test",
                    no_env=True,
                ),
                federation_invitation_writer=out,
                federation_invitation_no_browser_open=True,
            )
            try:
                client = DiskServiceClient(sdk)

                async def follow_link() -> None:
                    import re

                    for _ in range(200):
                        s = out.getvalue()
                        m = re.search(r"https?://[^\s]+", s)
                        if m:
                            url = m.group(0)
                            async with aiohttp.ClientSession() as session:
                                try:
                                    await session.get(url, allow_redirects=True)
                                except Exception:
                                    pass
                            return
                        await asyncio.sleep(0.05)

                task = asyncio.create_task(follow_link())
                await client.list(V1List())
                await task
            finally:
                await sdk.close()
        finally:
            await srv.stop(0)
    finally:
        await runner.cleanup()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v2/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v2 import access_key_pb2 as nebius_dot_iam_dot_v2_dot_access__key__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v2/access_key_service.proto\x12\rnebius.iam.v2\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v2/access_key.proto\x1a\x1anebius/iam/v1/access.proto\"\x8a\x01\n\x16\x43reateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v2.AccessKeySpecR\x04spec\"%\n\x13GetAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"+\n\x19GetAccessKeySecretRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"G\n\x1aGetAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"\x88\x01\n\x15ListAccessKeysRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\xa6\x01\n\x1eListAccessKeysByAccountRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountR\x07\x61\x63\x63ount\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"\x8a\x01\n\x16UpdateAccessKeyRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v2.AccessKeySpecR\x04spec\"*\n\x18\x41\x63tivateAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\",\n\x1a\x44\x65\x61\x63tivateAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"L\n\x1f\x41\x63tivateAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"N\n!DeactivateAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"(\n\x16\x44\x65leteAccessKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"J\n\x1d\x44\x65leteAccessKeyByAwsIdRequest\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\"d\n\x1aGetAccessKeySecretResponse\x12)\n\x11\x61ws_access_key_id\x18\x01 \x01(\tR\x0e\x61wsAccessKeyId\x12\x1b\n\x06secret\x18\x02 \x01(\tB\x03\xc0J\x01R\x06secret\"p\n\x16ListAccessKeysResponse\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x18.nebius.iam.v2.AccessKeyR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x86\t\n\x10\x41\x63\x63\x65ssKeyService\x12L\n\x06\x43reate\x12%.nebius.iam.v2.CreateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12\x43\n\x03Get\x12\".nebius.iam.v2.GetAccessKeyRequest\x1a\x18.nebius.iam.v2.AccessKey\x12`\n\tGetSecret\x12(.nebius.iam.v2.GetAccessKeySecretRequest\x1a).nebius.iam.v2.GetAccessKeySecretResponse\x12S\n\x04List\x12$.nebius.iam.v2.ListAccessKeysRequest\x1a%.nebius.iam.v2.ListAccessKeysResponse\x12L\n\x06Update\x12%.nebius.iam.v2.UpdateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12L\n\x06\x44\x65lete\x12%.nebius.iam.v2.DeleteAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12P\n\x08\x41\x63tivate\x12\'.nebius.iam.v2.ActivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12T\n\nDeactivate\x12).nebius.iam.v2.DeactivateAccessKeyRequest\x1a\x1b.nebius.common.v1.Operation\x12\x65\n\rListByAccount\x12-.nebius.iam.v2.ListAccessKeysByAccountRequest\x1a%.nebius.iam.v2.ListAccessKeysResponse\x12Q\n\nGetByAwsId\x12).nebius.iam.v2.GetAccessKeyByAwsIdRequest\x1a\x18.nebius.iam.v2.AccessKey\x12Z\n\rDeleteByAwsId\x12,.nebius.iam.v2.DeleteAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x12^\n\x0f\x41\x63tivateByAwsId\x12..nebius.iam.v2.ActivateAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x12\x62\n\x11\x44\x65\x61\x63tivateByAwsId\x12\x30.nebius.iam.v2.DeactivateAccessKeyByAwsIdRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB\\\n\x14\x61i.nebius.pub.iam.v2B\x15\x41\x63\x63\x65ssKeyServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v2.access_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v2B\025AccessKeyServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v2'
  _GETACCESSKEYSECRETRESPONSE.fields_by_name['secret']._options = None
  _GETACCESSKEYSECRETRESPONSE.fields_by_name['secret']._serialized_options = b'\300J\001'
  _ACCESSKEYSERVICE._options = None
  _ACCESSKEYSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEACCESSKEYREQUEST']._serialized_start=211
  _globals['_CREATEACCESSKEYREQUEST']._serialized_end=349
  _globals['_GETACCESSKEYREQUEST']._serialized_start=351
  _globals['_GETACCESSKEYREQUEST']._serialized_end=388
  _globals['_GETACCESSKEYSECRETREQUEST']._serialized_start=390
  _globals['_GETACCESSKEYSECRETREQUEST']._serialized_end=433
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_start=435
  _globals['_GETACCESSKEYBYAWSIDREQUEST']._serialized_end=506
  _globals['_LISTACCESSKEYSREQUEST']._serialized_start=509
  _globals['_LISTACCESSKEYSREQUEST']._serialized_end=645
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_start=648
  _globals['_LISTACCESSKEYSBYACCOUNTREQUEST']._serialized_end=814
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_start=817
  _globals['_UPDATEACCESSKEYREQUEST']._serialized_end=955
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_start=957
  _globals['_ACTIVATEACCESSKEYREQUEST']._serialized_end=999
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_start=1001
  _globals['_DEACTIVATEACCESSKEYREQUEST']._serialized_end=1045
  _globals['_ACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_start=1047
  _globals['_ACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_end=1123
  _globals['_DEACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_start=1125
  _globals['_DEACTIVATEACCESSKEYBYAWSIDREQUEST']._serialized_end=1203
  _globals['_DELETEACCESSKEYREQUEST']._serialized_start=1205
  _globals['_DELETEACCESSKEYREQUEST']._serialized_end=1245
  _globals['_DELETEACCESSKEYBYAWSIDREQUEST']._serialized_start=1247
  _globals['_DELETEACCESSKEYBYAWSIDREQUEST']._serialized_end=1321
  _globals['_GETACCESSKEYSECRETRESPONSE']._serialized_start=1323
  _globals['_GETACCESSKEYSECRETRESPONSE']._serialized_end=1423
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_start=1425
  _globals['_LISTACCESSKEYSRESPONSE']._serialized_end=1537
  _globals['_ACCESSKEYSERVICE']._serialized_start=1540
  _globals['_ACCESSKEYSERVICE']._serialized_end=2698
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import cluster_service_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2


class ClusterServiceStub(object):
    """A set of methods for managing PostgreSQL Cluster resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Get',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/GetByName',
                request_serializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
                )
        self.GetForBackup = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/GetForBackup',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterForBackupRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/List',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Create',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Delete',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Update',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Restore = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Restore',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.RestoreClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Stop',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StopClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/nebius.msp.postgresql.v1alpha1.ClusterService/Start',
                request_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StartClusterRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
                )


class ClusterServiceServicer(object):
    """A set of methods for managing PostgreSQL Cluster resources.
    """

    def Get(self, request, context):
        """Returns the specified PostgreSQL Cluster resource.
        To get the list of available PostgreSQL Cluster resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Returns the specified PostgreSQL Cluster resource by name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForBackup(self, request, context):
        """Returns the specified PostgreSQL Cluster resource for backup.
        It should be used as a hint of cluster configuration in case of backup restoration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of PostgreSQL Cluster resources that belong
        to the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a PostgreSQL cluster in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified PostgreSQL cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the PostgreSQL cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Restore(self, request, context):
        """Creates a new PostgreSQL cluster from a previously created backup.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Suspends the PostgreSQL cluster to save resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Wakes up suspended PostgreSQL cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'GetForBackup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForBackup,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterForBackupRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersRequest.FromString,
                    response_serializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.CreateClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.UpdateClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Restore': grpc.unary_unary_rpc_method_handler(
                    servicer.Restore,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.RestoreClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StopClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StartClusterRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.msp.postgresql.v1alpha1.ClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClusterService(object):
    """A set of methods for managing PostgreSQL Cluster resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Get',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/GetByName',
            nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForBackup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/GetForBackup',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.GetClusterForBackupRequest.SerializeToString,
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/List',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.ListClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Create',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Delete',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Update',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Restore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Restore',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.RestoreClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Stop',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StopClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.msp.postgresql.v1alpha1.ClusterService/Start',
            nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__service__pb2.StartClusterRequest.SerializeToString,
            nebius_dot_common_dot_v1alpha1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class AuthenticationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    AUTHENTICATION_TYPE_UNSPECIFIED: _ClassVar[AuthenticationType]
    ACCESS_TOKEN: _ClassVar[AuthenticationType]
    STATIC_KEY: _ClassVar[AuthenticationType]
AUTHENTICATION_TYPE_UNSPECIFIED: AuthenticationType
ACCESS_TOKEN: AuthenticationType
STATIC_KEY: AuthenticationType
